=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2011-05-27 02:17:10 +0000
+++ bzrlib/lockdir.py	2011-05-27 02:22:23 +0000
@@ -818,7 +818,7 @@
             mutter("can't parse pid %r from %r" 
                 % (pid_str, self))
             return False
-        return osutils._posix_is_local_pid_dead(pid)
+        return osutils.is_local_pid_dead(pid)
 
 
 def get_username_for_lock_info():

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2011-05-27 02:21:57 +0000
+++ bzrlib/osutils.py	2011-05-27 02:22:23 +0000
@@ -2469,3 +2469,7 @@
         # Exists and our process: not dead.
         return False
 
+if sys.platform == "win32":
+    is_local_pid_dead = win32utils.is_local_pid_dead
+else:
+    is_local_pid_dead = _posix_is_local_pid_dead

=== modified file 'bzrlib/win32utils.py'
--- bzrlib/win32utils.py	2011-05-18 16:42:48 +0000
+++ bzrlib/win32utils.py	2011-05-27 02:22:23 +0000
@@ -576,3 +576,41 @@
         return argv
 else:
     get_unicode_argv = None
+
+
+if has_win32api:
+    def _pywin32_is_local_pid_dead(pid):
+        """True if pid doesn't correspond to live process on this machine"""
+        try:
+            handle = win32api.OpenProcess(1, False, pid) # PROCESS_TERMINATE
+        except pywintypes.error, e:
+            if e[0] == 1: # ERROR_ACCESS_DENIED
+                # Probably something alive we're not allowed to kill
+                return False
+            elif e[0] == 87: # ERROR_INVALID_PARAMETER
+                return True
+            raise
+        handle.close()
+        return False
+    is_local_pid_dead = _pywin32_is_local_pid_dead
+elif has_ctypes:
+    from ctypes.wintypes import BOOL, DWORD, HANDLE
+    _kernel32 = ctypes.windll.kernel32
+    _CloseHandle = ctypes.WINFUNCTYPE(BOOL, HANDLE)(
+        ("CloseHandle", _kernel32))
+    _OpenProcess = ctypes.WINFUNCTYPE(HANDLE, DWORD, BOOL, DWORD)(
+        ("OpenProcess", _kernel32))
+    def _ctypes_is_local_pid_dead(pid):
+        """True if pid doesn't correspond to live process on this machine"""
+        handle = _OpenProcess(1, False, pid) # PROCESS_TERMINATE
+        if not handle:
+            errorcode = ctypes.GetLastError()
+            if errorcode == 1: # ERROR_ACCESS_DENIED
+                # Probably something alive we're not allowed to kill
+                return False
+            elif errorcode == 87: # ERROR_INVALID_PARAMETER
+                return True
+            raise ctypes.WinError(errorcode)
+        _CloseHandle(handle)
+        return False
+    is_local_pid_dead = _ctypes_is_local_pid_dead

